@@ -46,4 +46,4 @@ class GeometricProgression:
 
     def get_sum_to_nth(self, n):
         if self.q == 1: return n * self.b[0]
-        return (self.b[0] * ((self.q[0] ** (n - 1)) - 1)) // (self.q - 1)
+        return (self.b[0] * ((self.q ** n) - 1)) // (self.q - 1)
